@@ -6,6 +6,7 @@ import project
 import dolly
 import terminal
 import sys
+import os
 
 def isGitRepo(repo):
 	return repo['remote'].endswith('.git')
@@ -13,6 +14,9 @@ def isGitRepo(repo):
 def isSvnCheckout(repo):
     return os.path.exists(repo['local'] + '/.svn')
 
+def isGitCheckout(repo):
+    return os.path.exists(repo['local'] + '/.git')
+
 def executeCommand(command, cwd=None):
 	proc = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=cwd)
 	if dolly.Dolly.verbose:
@@ -30,6 +34,7 @@ def executeCommand(command, cwd=None):
 		terminal.error(stderr)
 	return {'returncode': returncode, 'stdout': stdout, 'stderr': stderr}
 
+
 def printStatus(repo, count=True):
 	if dolly.Dolly.verbose or count==False:
 		if count:
