@@ -24,6 +24,11 @@ class Status:
 			self.statusSvn(repo)
 
 	def statusGit(self, repo):
+		if not util.isGitCheckout(repo):
+			error = "\n{0} is a Git repo in config file but not a Git checkout on disk".format(repo['local'])
+			terminal.error(error)
+			dolly.Dolly.warnings.append(error)
+			return
 		result = util.executeCommand('git status -s', cwd=repo['local'])
 		for line in result['stdout'].splitlines():
 			change = os.path.join(repo['local'], ' '.join(line.split()[1:]))
@@ -35,6 +40,11 @@ class Status:
 
 
 	def statusSvn(self, repo):
+		if not util.isSvnCheckout(repo):
+			error = "\n{0} is a Svn repo in config file but not a Svn checkout on disk".format(repo['local'])
+			terminal.error(error)
+			dolly.Dolly.warnings.append(error)
+			return
 		result = util.executeCommand('svn status', cwd=repo['local'])
 		for line in result['stdout'].splitlines():
 			change = os.path.join(repo['local'], ' '.join(line.split()[1:]))
